pub fn diff(old: &str, new: &str) -> DiffResultExpand description
Compute a line-level diff between two texts using the Myers O(ND) algorithm.
pub fn diff(old: &str, new: &str) -> DiffResultCompute a line-level diff between two texts using the Myers O(ND) algorithm.