diff_to_patches

Function diff_to_patches 

pub fn diff_to_patches(
    new: &str,
    result: &DiffResult,
) -> Result<Vec<TextPatch>, TextPatchError>
Convert a diff result to a list of TextPatch values that can be applied to the old text.