pub fn diff_to_patches(
new: &str,
result: &DiffResult,
) -> Result<Vec<TextPatch>, TextPatchError>Expand description
Convert a diff result to a list of TextPatch values that can be applied to the old text.
pub fn diff_to_patches(
new: &str,
result: &DiffResult,
) -> Result<Vec<TextPatch>, TextPatchError>Convert a diff result to a list of TextPatch values that can be applied to the old text.